Changelog
=========

`2.2.0`_
--------

- if message has image, don't keep checking for other conditions.
- save cache in the bot account's folder.

`2.1.0`_
--------

- make search case insensitive.
- add ``/info`` command.
- improve HTML search results.
- reduce metadata refresh rate.
- pack that are too big are now uploaded to a cloud instead of sending them directly.
- allow to convert Telegram stickers (``.tgs``) to ``.webp``

`2.0.0`_
--------

- removed ``/sticker`` command.
- allow to search for sticker packs.
- allow to get a random sticker for an emoji.
- delete zipped pack after it is sent.
- cache stickers and packs metadata.
- limit the size of the zipped pack.

1.0.0
-----

- initial release


.. _Unreleased: https://github.com/adbenitez/simplebot_stickers/compare/v2.2.0...HEAD
.. _2.2.0: https://github.com/adbenitez/simplebot_stickers/compare/v2.1.0...v2.2.0
.. _2.1.0: https://github.com/adbenitez/simplebot_stickers/compare/v2.0.0...v2.1.0
.. _2.0.0: https://github.com/adbenitez/simplebot_stickers/compare/v1.0.0...v2.0.0
